@@ -193,14 +193,9 @@ make_color_ramp (int       h1,
                  gboolean  closed) {
     double dh, ds, dv;        /* deltas */
     int    i;
-    int    ncolors, wanted;
+    int    ncolors;
     int    total_ncolors = n_colors;
 
-    wanted = total_ncolors;
-    if (closed) {
-        wanted = (wanted / 2) + 1;
-    }
-
     ncolors = total_ncolors;
 
     memset (colors, 0, n_colors * sizeof (*colors));
@@ -451,10 +446,8 @@ static void
 draw_frame (GSTEPopsquares *pop,
             cairo_t        *cr) {
     int      border = 1;
-    gboolean twitch = FALSE;
     int      x, y;
     int      gw, gh;
-    int      nsquares;
     int      window_width;
     int      window_height;
     GdkWindow *window;
@@ -471,7 +464,6 @@ draw_frame (GSTEPopsquares *pop,
 
     gw = pop->priv->subdivision;
     gh = pop->priv->subdivision;
-    nsquares = gw * gh;
 
     for (y = 0; y < gh; y++) {
         for (x = 0; x < gw; x++) {
@@ -479,17 +471,13 @@ draw_frame (GSTEPopsquares *pop,
 
             gdk_cairo_set_source_rgba (cr, &(pop->priv->colors[s->color]));
             cairo_rectangle (cr, s->x, s->y,
-                             border ? s->w - border : s->w,
-                             border ? s->h - border : s->h);
+                             s->w - border,
+                             s->h - border);
             cairo_fill (cr);
             s->color++;
 
             if (s->color == pop->priv->ncolors) {
-                if (twitch && ((g_random_int_range (0, 4)) == 0)) {
-                    randomize_square_colors (pop->priv->squares, nsquares, pop->priv->ncolors);
-                } else {
-                    s->color = g_random_int_range (0, pop->priv->ncolors);
-                }
+                s->color = g_random_int_range (0, pop->priv->ncolors);
             }
         }
     }
@@ -502,16 +490,16 @@ draw_iter (GSTEPopsquares *pop) {
 }
 
 static void
-gste_popsquares_init (GSTEPopsquares *pop) {
+gste_popsquares_init (GSTEPopsquares *engine) {
     int delay;
 
-    pop->priv = gste_popsquares_get_instance_private (pop);
+    engine->priv = gste_popsquares_get_instance_private (engine);
 
-    pop->priv->ncolors = 128;
-    pop->priv->subdivision = 5;
+    engine->priv->ncolors = 128;
+    engine->priv->subdivision = 5;
 
     delay = 25;
-    pop->priv->timeout_id = g_timeout_add (delay, (GSourceFunc)draw_iter, pop);
+    engine->priv->timeout_id = g_timeout_add (delay, (GSourceFunc)draw_iter, engine);
 }
 
 static void
