@@ -125,7 +125,6 @@ enum {
 enum {
     PROP_0,
     PROP_ACTIVE,
-    PROP_SESSION_IDLE,
 };
 
 enum {
@@ -312,17 +311,13 @@ listener_check_activation (GSListener *listener) {
         return TRUE;
     }
 
-    if (!listener->priv->session_idle) {
-        return TRUE;
-    }
-
     /* if we aren't inhibited then activate */
     inhibited = listener_ref_entry_is_present (listener, REF_ENTRY_TYPE_INHIBIT);
 
     res = FALSE;
     if (!inhibited) {
         gs_debug ("Trying to activate");
-        res = gs_listener_set_active (listener, TRUE);
+        res = gs_listener_activate_saver (listener, TRUE);
     }
 
     return res;
@@ -357,30 +352,11 @@ listener_check_throttle (GSListener *listener) {
     return TRUE;
 }
 
-static gboolean
-listener_set_session_idle_internal (GSListener *listener,
-                                    gboolean    idle) {
-    listener->priv->session_idle = idle;
-
-    if (idle) {
-        listener->priv->session_idle_start = time (NULL);
-    } else {
-        listener->priv->session_idle_start = 0;
-    }
-
-    return TRUE;
-}
-
 static gboolean
 listener_set_active_internal (GSListener *listener,
                               gboolean    active) {
     listener->priv->active = active;
 
-    /* if idle not in sync with active, change it */
-    if (listener->priv->session_idle != active) {
-        listener_set_session_idle_internal (listener, active);
-    }
-
     if (active) {
         listener->priv->active_start = time (NULL);
     } else {
@@ -393,8 +369,8 @@ listener_set_active_internal (GSListener *listener,
 }
 
 gboolean
-gs_listener_set_active (GSListener *listener,
-                        gboolean    active) {
+gs_listener_activate_saver (GSListener *listener,
+                            gboolean    active) {
     gboolean res;
 
     g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
@@ -405,65 +381,12 @@ gs_listener_set_active (GSListener *listener,
         return FALSE;
     }
 
-    res = FALSE;
     g_signal_emit (listener, signals[ACTIVE_CHANGED], 0, active, &res);
-    if (!res) {
-        /* if the signal is not handled then we haven't changed state */
-        gs_debug ("Active-changed signal not handled");
-
-        /* clear the idle state */
-        if (active) {
-            listener_set_session_idle_internal (listener, FALSE);
-        }
-
-        return FALSE;
-    }
-
     listener_set_active_internal (listener, active);
 
     return TRUE;
 }
 
-gboolean
-gs_listener_set_session_idle (GSListener *listener,
-                              gboolean    idle) {
-    gboolean res;
-
-    g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
-
-    gs_debug ("Setting session idle: %d", idle);
-
-    if (listener->priv->session_idle == idle) {
-        gs_debug ("Trying to set idle state when already %s",
-                  idle ? "idle" : "not idle");
-        return FALSE;
-    }
-
-    if (idle) {
-        gboolean inhibited;
-
-        inhibited = listener_ref_entry_is_present (listener, REF_ENTRY_TYPE_INHIBIT);
-
-        /* if we are inhibited then do nothing */
-        if (inhibited) {
-            return FALSE;
-        }
-    }
-
-    listener->priv->session_idle = idle;
-    res = listener_check_activation (listener);
-
-    /* if activation fails then don't set idle */
-    if (res) {
-        listener_set_session_idle_internal (listener, idle);
-    } else {
-        gs_debug ("Idle activation failed");
-        listener->priv->session_idle = !idle;
-    }
-
-    return res;
-}
-
 static dbus_bool_t
 listener_property_set_bool (GSListener  *listener,
                             guint        prop_id,
@@ -474,7 +397,7 @@ listener_property_set_bool (GSListener  *listener,
 
     switch (prop_id) {
         case PROP_ACTIVE:
-            gs_listener_set_active (listener, value);
+            gs_listener_activate_saver (listener, value);
             ret = TRUE;
             break;
         default:
@@ -1420,7 +1343,7 @@ listener_dbus_handle_system_message (DBusConnection *connection,
         if (dbus_message_is_signal (message, LOGIND_SESSION_INTERFACE, "Unlock")) {
             if (_listener_message_path_is_our_session (listener, message)) {
                 gs_debug ("Systemd requested session unlock");
-                gs_listener_set_active (listener, FALSE);
+                gs_listener_activate_saver (listener, FALSE);
             }
 
             return DBUS_HANDLER_RESULT_HANDLED;
@@ -1462,13 +1385,8 @@ listener_dbus_handle_system_message (DBusConnection *connection,
                 if (properties_changed_match (message, "Active")) {
                     gboolean new_active;
 
-                    /* Instead of going via the
-                     * bus to read the new
-                     * property state, let's
-                     * shortcut this and ask
-                     * directly the low-level
-                     * information */
-
+                    /* Instead of going via the bus to read the new property state, let's
+                     * shortcut this and ask directly the low-level information */
                     new_active = sd_session_is_active (listener->priv->session_id) != 0;
                     if (new_active)
                         g_signal_emit (listener, signals[SIMULATE_USER_ACTIVITY], 0);
@@ -1509,7 +1427,7 @@ listener_dbus_handle_system_message (DBusConnection *connection,
     } else if (dbus_message_is_signal (message, CK_SESSION_INTERFACE, "Unlock")) {
         if (_listener_message_path_is_our_session (listener, message)) {
             gs_debug ("Console kit requested session unlock");
-            gs_listener_set_active (listener, FALSE);
+            gs_listener_activate_saver (listener, FALSE);
         }
 
         return DBUS_HANDLER_RESULT_HANDLED;
@@ -1749,10 +1667,7 @@ gs_listener_set_property (GObject      *object,
 
     switch (prop_id) {
         case PROP_ACTIVE:
-            gs_listener_set_active (self, g_value_get_boolean (value));
-            break;
-        case PROP_SESSION_IDLE:
-            gs_listener_set_session_idle (self, g_value_get_boolean (value));
+            gs_listener_activate_saver (self, g_value_get_boolean (value));
             break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
@@ -1773,9 +1688,6 @@ gs_listener_get_property (GObject    *object,
         case PROP_ACTIVE:
             g_value_set_boolean (value, self->priv->active);
             break;
-        case PROP_SESSION_IDLE:
-            g_value_set_boolean (value, self->priv->session_idle);
-            break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
             break;
