@@ -76,7 +76,7 @@ GType       gs_listener_get_type                        (void);
 GSListener *gs_listener_new                             (void);
 gboolean    gs_listener_acquire                         (GSListener *listener,
                                                          GError    **error);
-gboolean    gs_listener_set_active                      (GSListener *listener,
+gboolean    gs_listener_activate_saver                  (GSListener *listener,
                                                          gboolean    active);
 gboolean    gs_listener_set_session_idle                (GSListener *listener,
                                                          gboolean    idle);
