@@ -69,11 +69,11 @@ struct GSWindowPrivate {
     guint            dialog_up : 1;
 
     gboolean         lock_active;
-    gboolean         saver_active;
     char            *status_message;
     GSPrefs         *prefs;
 
     GtkWidget       *vbox;
+    GtkWidget       *overlay;
     GtkWidget       *drawing_area;
     GtkWidget       *lock_box;
     GtkWidget       *lock_socket;
@@ -81,8 +81,6 @@ struct GSWindowPrivate {
     GtkWidget       *info_bar;
     GtkWidget       *info_content;
 
-    cairo_surface_t *background_surface;
-
     guint            popup_dialog_idle_id;
 
     guint            dialog_map_signal_id;
@@ -95,8 +93,6 @@ struct GSWindowPrivate {
     gint             lock_pid;
     gint             lock_watch_id;
     gint             dialog_response;
-    gboolean         dialog_quit_requested;
-    gboolean         dialog_shake_in_progress;
 
     gint             keyboard_pid;
     gint             keyboard_watch_id;
@@ -712,17 +708,9 @@ window_select_shape_events (GSWindow *window) {
 static gboolean
 gs_window_real_draw (GtkWidget *widget,
                      cairo_t   *cr) {
-    GSWindow        *window = GS_WINDOW (widget);
-    cairo_surface_t *bg_surface = window->priv->background_surface;
-
     cairo_set_operator (cr, CAIRO_OPERATOR_OVER);
-    if (bg_surface != NULL) {
-        cairo_set_source_surface (cr, bg_surface, 0, 0);
-    } else {
-        cairo_set_source_rgb (cr, 0, 0, 0);
-    }
+    cairo_set_source_rgb (cr, 0, 0, 0);
     cairo_paint (cr);
-
     return FALSE;
 }
 
@@ -1022,9 +1010,12 @@ static gboolean
 lock_plug_removed (GtkWidget *widget,
                    GSWindow  *window) {
     gtk_widget_hide (widget);
-    gtk_container_remove (GTK_CONTAINER (window->priv->vbox), GTK_WIDGET (window->priv->lock_box));
+    gtk_container_remove (GTK_CONTAINER (window->priv->overlay), GTK_WIDGET (window->priv->lock_box));
     window->priv->lock_box = NULL;
 
+    gtk_container_remove (GTK_CONTAINER (window->priv->vbox), GTK_WIDGET (window->priv->overlay));
+    window->priv->overlay = NULL;
+
     return TRUE;
 }
 
@@ -1038,7 +1029,7 @@ static gboolean
 keyboard_plug_removed (GtkWidget *widget,
                        GSWindow  *window) {
     gtk_widget_hide (widget);
-    gtk_container_remove (GTK_CONTAINER (window->priv->vbox), GTK_WIDGET (window->priv->keyboard_socket));
+    gtk_container_remove (GTK_CONTAINER (window->priv->overlay), GTK_WIDGET (window->priv->keyboard_socket));
 
     return TRUE;
 }
@@ -1081,6 +1072,16 @@ remove_key_events (GSWindow *window) {
     }
 }
 
+static void
+prefs_changed (GSPrefs  *prefs,
+               GSWindow *window) {
+    if (window->priv->prefs->keyboard_enabled) {
+        if (window->priv->keyboard_socket) {
+            gtk_widget_set_visible (window->priv->keyboard_socket, window->priv->prefs->keyboard_displayed);
+        }
+    }
+}
+
 static void
 lock_socket_show (GtkWidget *widget,
                   GSWindow  *window) {
@@ -1097,6 +1098,7 @@ lock_socket_destroyed (GtkWidget *widget,
     g_signal_handlers_disconnect_by_func (widget, lock_socket_destroyed, window);
     g_signal_handlers_disconnect_by_func (widget, lock_plug_added, window);
     g_signal_handlers_disconnect_by_func (widget, lock_plug_removed, window);
+    g_signal_handlers_disconnect_by_func (window->priv->prefs, prefs_changed, window);
 
     window->priv->lock_socket = NULL;
 }
@@ -1104,12 +1106,36 @@ lock_socket_destroyed (GtkWidget *widget,
 static void
 create_keyboard_socket (GSWindow *window,
                         guint32   id) {
-    int height;
+    GdkDisplay   *display;
+    GdkMonitor   *monitor;
+    GdkWindow    *g_window;
+    GdkRectangle  geometry;
+    gint screen_height, screen_width;
+    gint height, width;
 
-    height = (HeightOfScreen (gdk_x11_screen_get_xscreen (gtk_widget_get_screen (GTK_WIDGET (window))))) / 4;
+    g_window = gtk_widget_get_window (GTK_WIDGET (window));
+    display = gdk_window_get_display (g_window);
+    monitor = gdk_display_get_monitor_at_window (display, g_window);
+    gdk_monitor_get_geometry (monitor, &geometry);
+
+    screen_height = geometry.height;
+    if (screen_height < 610) {
+        height = 205 - ((610 - screen_height) / 2); // Approximate, based on Greybird
+    } else {
+        height = 205; // Native height for onboard
+    }
+
+    screen_width = geometry.width;
+    if (screen_width < 1400) {
+        width = screen_width;
+    } else {
+        width = 1400; // Native width for onboard
+    }
 
     window->priv->keyboard_socket = gtk_socket_new ();
-    gtk_widget_set_size_request (window->priv->keyboard_socket, -1, height);
+    gtk_widget_set_size_request (window->priv->keyboard_socket, width, height);
+    gtk_widget_set_halign (window->priv->keyboard_socket, GTK_ALIGN_CENTER);
+    gtk_widget_set_valign (window->priv->keyboard_socket, GTK_ALIGN_END);
 
     g_signal_connect (window->priv->keyboard_socket, "destroy",
                       G_CALLBACK (keyboard_socket_destroyed), window);
@@ -1117,8 +1143,13 @@ create_keyboard_socket (GSWindow *window,
                       G_CALLBACK (keyboard_plug_added), window);
     g_signal_connect (window->priv->keyboard_socket, "plug_removed",
                       G_CALLBACK (keyboard_plug_removed), window);
-    gtk_box_pack_start (GTK_BOX (window->priv->vbox), window->priv->keyboard_socket, FALSE, FALSE, 0);
+
+    gtk_overlay_add_overlay (GTK_OVERLAY (window->priv->overlay), window->priv->keyboard_socket);
     gtk_socket_add_id (GTK_SOCKET (window->priv->keyboard_socket), id);
+
+    if (!window->priv->prefs->keyboard_displayed) {
+        gtk_widget_hide (window->priv->keyboard_socket);
+    }
 }
 
 /* adapted from gspawn.c */
@@ -1141,14 +1172,14 @@ wait_again:
 }
 
 static void
-kill_keyboard_command (GSWindow *window) {
+kill_keyboard_process (GSWindow *window) {
     if (window->priv->keyboard_pid > 0) {
         signal_pid (window->priv->keyboard_pid, SIGTERM);
     }
 }
 
 static void
-kill_dialog_command (GSWindow *window) {
+kill_dialog_process (GSWindow *window) {
     /* If a dialog is up we need to signal it
        and wait on it */
     if (window->priv->lock_pid > 0) {
@@ -1157,11 +1188,11 @@ kill_dialog_command (GSWindow *window) {
 }
 
 static void
-keyboard_command_finish (GSWindow *window) {
+keyboard_process_finish (GSWindow *window) {
     g_return_if_fail (GS_IS_WINDOW (window));
 
     /* send a signal just in case */
-    kill_keyboard_command (window);
+    kill_keyboard_process (window);
 
     gs_debug ("Keyboard finished");
 
@@ -1174,7 +1205,7 @@ keyboard_command_finish (GSWindow *window) {
 }
 
 static gboolean
-keyboard_command_watch (GIOChannel   *source,
+keyboard_process_watch (GIOChannel   *source,
                         GIOCondition  condition,
                         GSWindow     *window) {
     gboolean finished = FALSE;
@@ -1220,7 +1251,7 @@ keyboard_command_watch (GIOChannel   *source,
 
     if (finished) {
         window->priv->keyboard_watch_id = 0;
-        keyboard_command_finish (window);
+        keyboard_process_finish (window);
         return FALSE;
     }
 
@@ -1244,7 +1275,7 @@ embed_keyboard (GSWindow *window) {
     res = spawn_on_window (window,
                            window->priv->prefs->keyboard_command,
                            &window->priv->keyboard_pid,
-                           (GIOFunc)keyboard_command_watch,
+                           (GIOFunc)keyboard_process_watch,
                            window,
                            &window->priv->keyboard_watch_id);
     if (!res) {
@@ -1262,7 +1293,11 @@ create_lock_socket (GSWindow *window,
     gtk_widget_set_valign (GTK_WIDGET (window->priv->lock_box),
                            GTK_ALIGN_CENTER);
     gtk_widget_show (window->priv->lock_box);
-    gtk_box_pack_start (GTK_BOX (window->priv->vbox), window->priv->lock_box, TRUE, TRUE, 0);
+
+    window->priv->overlay = gtk_overlay_new ();
+    gtk_widget_show (window->priv->overlay);
+    gtk_box_pack_start (GTK_BOX (window->priv->vbox), window->priv->overlay, TRUE, TRUE, 0);
+    gtk_overlay_add_overlay (GTK_OVERLAY (window->priv->overlay), window->priv->lock_box);
 
     gtk_container_add (GTK_CONTAINER (window->priv->lock_box), window->priv->lock_socket);
 
@@ -1280,6 +1315,9 @@ create_lock_socket (GSWindow *window,
     if (window->priv->prefs->keyboard_enabled) {
         embed_keyboard (window);
     }
+
+    g_signal_connect (window->priv->prefs, "changed",
+                      G_CALLBACK (prefs_changed), window);
 }
 
 static void
@@ -1289,10 +1327,10 @@ gs_window_dialog_finish (GSWindow *window) {
     gs_debug ("Dialog finished");
 
     /* make sure we finish the keyboard thing too */
-    keyboard_command_finish (window);
+    keyboard_process_finish (window);
 
     /* send a signal just in case */
-    kill_dialog_command (window);
+    kill_dialog_process (window);
 
     if (window->priv->lock_pid > 0) {
         wait_on_child (window->priv->lock_pid);
@@ -1305,52 +1343,6 @@ gs_window_dialog_finish (GSWindow *window) {
     remove_key_events (window);
 }
 
-static void
-maybe_kill_dialog (GSWindow *window) {
-    if (!window->priv->dialog_shake_in_progress
-            && window->priv->dialog_quit_requested
-            && window->priv->lock_pid > 0) {
-        kill (window->priv->lock_pid, SIGTERM);
-    }
-}
-
-/* very rudimentary animation for indicating an auth failure */
-static void
-shake_dialog (GSWindow *window) {
-    int   i;
-    guint start, end;
-
-    window->priv->dialog_shake_in_progress = TRUE;
-
-    for (i = 0; i < 8; i++) {
-        if (i % 2 == 0) {
-            start = 30;
-            end = 0;
-        } else {
-            start = 0;
-            end = 30;
-        }
-
-        if (!window->priv->lock_box) {
-            break;
-        }
-
-        gtk_widget_set_margin_start (GTK_WIDGET (window->priv->lock_box),
-                                     start);
-        gtk_widget_set_margin_end (GTK_WIDGET (window->priv->lock_box),
-                                   end);
-
-        while (gtk_events_pending ()) {
-            gtk_main_iteration ();
-        }
-
-        g_usleep (10000);
-    }
-
-    window->priv->dialog_shake_in_progress = FALSE;
-    maybe_kill_dialog (window);
-}
-
 static void
 window_set_dialog_up (GSWindow *window,
                       gboolean  dialog_up) {
@@ -1378,16 +1370,21 @@ popdown_dialog (GSWindow *window) {
     window->priv->last_y = -1;
 
     if (window->priv->lock_box != NULL) {
-        gtk_container_remove (GTK_CONTAINER (window->priv->vbox), GTK_WIDGET (window->priv->lock_box));
+        gtk_container_remove (GTK_CONTAINER (window->priv->overlay), GTK_WIDGET (window->priv->lock_box));
         window->priv->lock_box = NULL;
     }
 
+    if (window->priv->overlay != NULL) {
+        gtk_container_remove (GTK_CONTAINER (window->priv->vbox), GTK_WIDGET (window->priv->overlay));
+        window->priv->overlay = NULL;
+    }
+
     remove_popup_dialog_idle (window);
     remove_command_watches (window);
 }
 
 static gboolean
-lock_command_watch (GIOChannel   *source,
+dialog_process_watch (GIOChannel   *source,
                     GIOCondition  condition,
                     GSWindow     *window) {
     gboolean finished = FALSE;
@@ -1414,7 +1411,7 @@ lock_command_watch (GIOChannel   *source,
                     }
                 } else if (strstr (line, "NOTICE=") != NULL) {
                     if (strstr (line, "NOTICE=AUTH FAILED") != NULL) {
-                        shake_dialog (window);
+                        gs_debug ("Authorization failed");
                     }
                 } else if (strstr (line, "RESPONSE=") != NULL) {
                     if (strstr (line, "RESPONSE=OK") != NULL) {
@@ -1427,8 +1424,7 @@ lock_command_watch (GIOChannel   *source,
                     finished = TRUE;
                 } else if (strstr (line, "REQUEST QUIT") != NULL) {
                     gs_debug ("Got request for quit");
-                    window->priv->dialog_quit_requested = TRUE;
-                    maybe_kill_dialog (window);
+                    kill_dialog_process (window);
                 }
                 break;
             case G_IO_STATUS_EOF:
@@ -1553,14 +1549,11 @@ popup_dialog (GSWindow *window) {
     gtk_widget_queue_draw (GTK_WIDGET (window));
     set_invisible_cursor (gtk_widget_get_window (GTK_WIDGET (window)), FALSE);
 
-    window->priv->dialog_quit_requested = FALSE;
-    window->priv->dialog_shake_in_progress = FALSE;
-
     gs_debug ("Executing %s", command->str);
     result = spawn_on_window (window,
                               command->str,
                               &window->priv->lock_pid,
-                              (GIOFunc)lock_command_watch,
+                              (GIOFunc)dialog_process_watch,
                               window,
                               &window->priv->lock_watch_id);
     if (!result) {
@@ -1614,16 +1607,6 @@ gs_window_set_lock_active (GSWindow *window,
     window->priv->lock_active = active;
 }
 
-void
-gs_window_set_saver_active (GSWindow *window,
-                            gboolean  active) {
-    g_return_if_fail (GS_IS_WINDOW (window));
-
-    gs_debug("Setting saver active: %i", active);
-
-    window->priv->saver_active = active;
-}
-
 void
 gs_window_cancel_unlock_request (GSWindow  *window) {
     /* FIXME: This is a bit of a hammer approach...
@@ -2147,9 +2130,6 @@ gs_window_finalize (GObject *object) {
 
     gs_window_dialog_finish (window);
 
-    if (window->priv->background_surface) {
-        cairo_surface_destroy (window->priv->background_surface);
-    }
     G_OBJECT_CLASS (gs_window_parent_class)->finalize (object);
 }
 
